summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoStyleManager.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoStyleManager.h')
-rw-r--r--lib/kotext/KoStyleManager.h84
1 files changed, 44 insertions, 40 deletions
diff --git a/lib/kotext/KoStyleManager.h b/lib/kotext/KoStyleManager.h
index e6f0f57e..10dbf8e6 100644
--- a/lib/kotext/KoStyleManager.h
+++ b/lib/kotext/KoStyleManager.h
@@ -21,7 +21,7 @@
#define kostylist_h
#include <kdialogbase.h>
-#include <qstringlist.h>
+#include <tqstringlist.h>
#include <KoParagDia.h>
#include <KoFontTab.h>
@@ -30,21 +30,21 @@
#include <KoLayoutTab.h>
#include <KoLanguageTab.h>
#include <KoUnit.h>
-#include <qptrlist.h>
+#include <tqptrlist.h>
#include <KoStyleCollection.h>
//class KoFontChooser;
class KoParagStyle;
class KoStyleEditor;
class KoStyleManagerTab;
-class QCheckBox;
-class QComboBox;
-class QGridLayout;
-class QLineEdit;
-class QListBox;
-class QPushButton;
-class QTabWidget;
-class QWidget;
+class TQCheckBox;
+class TQComboBox;
+class TQGridLayout;
+class TQLineEdit;
+class TQListBox;
+class TQPushButton;
+class TQTabWidget;
+class TQWidget;
class KoTextDocument;
class KoStyleManagerPrivate;
@@ -54,12 +54,13 @@ class KoStyleManagerPrivate;
class KOTEXT_EXPORT KoStyleManager : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
enum { ShowIncludeInToc = 1 }; // bitfield for flags
- KoStyleManager( QWidget *_parent, KoUnit::Unit unit,
+ KoStyleManager( TQWidget *_parent, KoUnit::Unit unit,
const KoStyleCollection& styleCollection,
- const QString & activeStyleName,
+ const TQString & activeStyleName,
int flags = 0 );
virtual ~KoStyleManager();
@@ -69,7 +70,7 @@ public:
virtual void removeStyleTemplate( KoParagStyle *style )=0;
virtual void updateAllStyleLists()=0;
- virtual void updateStyleListOrder( const QStringList & list)=0;
+ virtual void updateStyleListOrder( const TQStringList & list)=0;
protected:
void updateFollowingStyle( KoParagStyle *s );
@@ -83,22 +84,22 @@ protected:
int styleIndex( int pos );
private:
- QTabWidget *m_tabs;
- QListBox *m_stylesList;
- QLineEdit *m_nameString;
- QComboBox *m_styleCombo;
- QPushButton *m_deleteButton;
- QPushButton *m_newButton;
- QPushButton *m_moveUpButton;
- QPushButton *m_moveDownButton;
- QComboBox *m_inheritCombo;
+ TQTabWidget *m_tabs;
+ TQListBox *m_stylesList;
+ TQLineEdit *m_nameString;
+ TQComboBox *m_styleCombo;
+ TQPushButton *m_deleteButton;
+ TQPushButton *m_newButton;
+ TQPushButton *m_moveUpButton;
+ TQPushButton *m_moveDownButton;
+ TQComboBox *m_inheritCombo;
KoStyleManagerPrivate *d;
KoParagStyle *m_currentStyle;
- QPtrList<KoParagStyle> m_origStyles; // internal list of orig styles we have modified
- QPtrList<KoParagStyle> m_changedStyles; // internal list of changed styles.
- QPtrList<KoStyleManagerTab> m_tabsList;
- QStringList m_styleOrder;
+ TQPtrList<KoParagStyle> m_origStyles; // internal list of orig styles we have modified
+ TQPtrList<KoParagStyle> m_changedStyles; // internal list of changed styles.
+ TQPtrList<KoStyleManagerTab> m_tabsList;
+ TQStringList m_styleOrder;
int numStyles;
bool noSignals;
@@ -111,46 +112,48 @@ protected slots:
void deleteStyle();
void moveUpStyle();
void moveDownStyle();
- void renameStyle(const QString &);
+ void renameStyle(const TQString &);
protected:
- KoParagStyle * style( const QString & _name );
+ KoParagStyle * style( const TQString & _name );
void addTab( KoStyleManagerTab * tab );
- QString generateUniqueName();
+ TQString generateUniqueName();
};
-class KOTEXT_EXPORT KoStyleManagerTab : public QWidget {
+class KOTEXT_EXPORT KoStyleManagerTab : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
public:
- KoStyleManagerTab(QWidget *parent) : QWidget(parent) {};
+ KoStyleManagerTab(TQWidget *tqparent) : TQWidget(tqparent) {};
/** the new style which is to be displayed */
void setStyle(KoParagStyle *style) { m_style = style; }
/** update the GUI from the current Style*/
virtual void update() = 0;
/** return the (i18n-ed) name of the tab */
- virtual QString tabName() = 0;
+ virtual TQString tabName() = 0;
/** save the GUI to the style */
virtual void save() = 0;
protected:
KoParagStyle *m_style;
};
-// A tab to edit parts of the parag-layout of the style
+// A tab to edit parts of the parag-tqlayout of the style
// Acts as a wrapper around KoParagLayoutWidget [which doesn't know about styles].
class KOTEXT_EXPORT KoStyleParagTab : public KoStyleManagerTab
{
Q_OBJECT
+ TQ_OBJECT
public:
- KoStyleParagTab( QWidget * parent );
+ KoStyleParagTab( TQWidget * tqparent );
- // not a constructor parameter since 'this' is the parent of the widget
+ // not a constructor parameter since 'this' is the tqparent of the widget
void setWidget( KoParagLayoutWidget * widget );
virtual void update();
virtual void save();
- virtual QString tabName() { return m_widget->tabName(); }
+ virtual TQString tabName() { return m_widget->tabName(); }
protected:
- virtual void resizeEvent( QResizeEvent *e );
+ virtual void resizeEvent( TQResizeEvent *e );
private:
KoParagLayoutWidget * m_widget;
};
@@ -159,11 +162,12 @@ private:
class KOTEXT_EXPORT KoStyleFontTab : public KoStyleManagerTab
{
Q_OBJECT
+ TQ_OBJECT
public:
- KoStyleFontTab( QWidget * parent );
+ KoStyleFontTab( TQWidget * tqparent );
~KoStyleFontTab();
virtual void update();
- virtual QString tabName();
+ virtual TQString tabName();
virtual void save();
private:
KoFontTab *m_fontTab;
@@ -177,7 +181,7 @@ private:
Font simple font dia
Color simple color dia
Spacing and Indents paragraph spacing dia (KWParagDia)
-alignments KoParagDia alignment tab
+tqalignments KoParagDia tqalignment tab
borders KoParagDia borders tab
numbering KoParagDia tab numbering
tabulators KoParagDia tab tabs */